@@ -1,6 +1,6 @@
 use std::{env, path::PathBuf};
 
-use clap_generate::generators::{Bash, Elvish, Fish, Zsh};
+use clap_generate::generators::{Bash, Elvish, Fish, PowerShell, Zsh};
 use mit_build_tools::{completion, manpage};
 
 #[path = "src/cli/app.rs"]
@@ -15,6 +15,7 @@ fn main() {
     completion::generate::<Fish>(&app, &out_dir.join("fish_completion"));
     completion::generate::<Zsh>(&app, &out_dir.join("zsh_completion"));
     completion::generate::<Bash>(&app, &out_dir.join("bash_completion"));
+    completion::generate::<PowerShell>(&app, &out_dir.join("power_shell_completion"));
 
     manpage::generate(&app, &out_dir, "docs/manpage.template.md");
 }
